@@ -1,12 +1,12 @@
 #' Parse casting formulae.
-#' 
+#'
 #' There are a two ways to specify a casting formula: either as a string, or
 #' a list of quoted variables. This function converts the former to the
-#' latter. 
-#' 
+#' latter.
+#'
 #' Casting formulas separate dimensions with \code{~} and variables within
-#' a dimension with \code{+} or \code{*}. \code{.} can be used as a 
-#' placeholder, and \code{...} represents all other variables not otherwise 
+#' a dimension with \code{+} or \code{*}. \code{.} can be used as a
+#' placeholder, and \code{...} represents all other variables not otherwise
 #' used.
 #'
 #' @param formula formula to parse
@@ -21,11 +21,11 @@ parse_formula <- function(formula = "...  ~ variable", varnames, value.var = "va
   replace.remainder <- function(x) {
     if (any(x == "...")) c(x[x != "..."], remainder) else x
   }
-  
-  if (is.formula(formula)) {
+
+  if (inherits(formula, "formula")) {
     formula <- str_c(deparse(formula, 500), collapse = "")
   }
-  
+
   if (is.character(formula)) {
     dims <- str_split(formula, fixed("~"))[[1]]
     formula <- lapply(str_split(dims, "[+*]"), str_trim)
@@ -38,10 +38,10 @@ parse_formula <- function(formula = "...  ~ variable", varnames, value.var = "va
       formula <- lapply(formula, replace.remainder)
     }
   }
-  
+
   if (!is.list(formula)) {
     stop("Don't know how to parse", formula, call. = FALSE)
   }
-  
+
   lapply(formula, as.quoted)
 }
